"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transform = exports.shouldTransform = void 0;
const magic_string_1 = require("magic-string");
const ref_transform_1 = require("@vue/ref-transform");
const parseSFC_1 = require("./parseSFC");
const transformScriptSetup_1 = require("./transformScriptSetup");
const transformSfcRefSugar_1 = require("./transformSfcRefSugar");
const options_1 = require("./options");
const scriptSetupRE = /<script\s(.*\s)?setup(\s.*)?>/;
function shouldTransform(code, id, options) {
    // avoid transforming twice
    if (code.includes('export default __sfc_main'))
        return false;
    return ((options === null || options === void 0 ? void 0 : options.refTransform) && (0, ref_transform_1.shouldTransform)(code)) || scriptSetupRE.test(code);
}
exports.shouldTransform = shouldTransform;
function transform(input, id, options) {
    if (!shouldTransform(input, id, options))
        return null;
    const resolved = (0, options_1.resolveOptions)(options);
    if (id.endsWith('.vue') || id.includes('.vue?vue'))
        return transformVue(input, id, resolved);
    else
        return transformNonVue(input, id, resolved);
}
exports.transform = transform;
function transformNonVue(input, id, options) {
    if (options.refTransform && (0, ref_transform_1.shouldTransform)(input)) {
        return (0, ref_transform_1.transform)(input, {
            filename: id,
            sourceMap: options.sourceMap,
            importHelpersFrom: options.importHelpersFrom,
        });
    }
    return null;
}
function transformVue(input, id, options) {
    const s = new magic_string_1.default(input);
    const sfc = (0, parseSFC_1.parseSFC)(input, id);
    if (options.refTransform)
        (0, transformSfcRefSugar_1.transformSfcRefSugar)(sfc, options);
    const { code } = (0, transformScriptSetup_1.transformScriptSetup)(sfc, options);
    const attributes = Object.assign(Object.assign({}, sfc.script.attrs), sfc.scriptSetup.attrs);
    delete attributes.setup;
    const attr = Object.entries(attributes)
        .map(([key, value]) => value ? `${key}="${value}"` : key)
        .join(' ');
    if (code) {
        const block = `<script ${attr}>\n${code}\n</script>`;
        s.remove(sfc.script.start, sfc.script.end);
        if (sfc.scriptSetup.start !== sfc.scriptSetup.end) {
            s.overwrite(sfc.scriptSetup.start, sfc.scriptSetup.end, block);
        }
        else {
            s.prependLeft(0, `${block}\n`);
        }
    }
    return {
        code: s.toString(),
        map: options.sourceMap
            ? s.generateMap({
                source: id,
                includeContent: true,
            })
            : null,
    };
}
